@@ -163,11 +163,11 @@ def _post_sendgrid_mail(mail_data: Dict, conn_id: str = "sendgrid_default") -> N
     try:
         response = sendgrid_client.client.mail.send.post(request_body=mail_data)
     except HTTPError as e:
-        message = f"Failed to send email. With HTTPError: {e}"
+        message = f"Failed to send email. With HTTPError: {e} and mail_data: {mail_data}"
         log.info(message)
         raise e
     except Exception as e:
-        bare_message = f"Failed to send email. With: {e}"
+        bare_message = f"Failed to send email. With: {e} and mail_data: {mail_data}"
         log.info(bare_message)
         raise ValueError(bare_message) from e
     # 2xx status code.
